; Boulder Dash intro tune - chip version
; (Last updated 9th of July, 2005)
;
; Adapted for the Atari 2600 by Erik Ehrling (Sweden)
; email: "erik_ehrling 'at' hotmail 'dot' com"
;
; The overall goal has been to keep the this chip version 
; as close as possible to the original and also make it 
; sound somewhat like a chip version on a 'bigger' 8-bit 
; machine. Maybe a second goal has been to make it more 
; catchy than the original - which by some people is 
; considered a bit on the dull side.
;
; This updated version should fix some of the rough and 
; blippy sound of my first rendition of the tune 
; (posted as bd2600.bin in the forum at atariage.com)
;
; The melody has been transposed down one octave in order to
; better fit the limited tone capabilities of the 2600. 
; Also, as it stretches over four octaves it is played on 
; a combination of lead, square and saw to cover for all notes
; required. Some of the notes have then been been tweaked to 
; improve the overall experience of the song.
;
; This song uses a music driver by Paul Slocum (from Music 
; Kit v2.0). The music driver is used here in unmodified form. 
; Most comments have been retained for increased readability.
;
; Run in Z26 at fixed 60 fps for true NTSC speed, e.g.:
; z26 -r60 -d2 bdchip.bin
;-------------------------------------------------------------
; SONG DATA FILE
;-------------------------------------------------------------
;
;-------------------------------------------------------------
; Tempo
;-------------------------------------------------------------
; TEMPODELAY sets the song tempo.  Higher values mean a slower
; song.  1 is extremely fast and 10 is very slow.  The tempo 
; is currently only adjustable in very large increments.
; Future versions of the software will allow more precise tempo
; settings.  Typically I use a TEMPODELAY or 3 or 4.

TEMPODELAY equ 2

;-------------------------------------------------------------
; Sound Attenuation Array
;-------------------------------------------------------------
; This section allows you to change the volume
; of each sound type globally.  Many times you'll
; have a certain sound that ends up being too loud,
; You can fix that here.  Note that a larger value
; makes the sound quieter.  Set all 8 values to zero
; if you want all sounds at full volume.  10 is probably 
; about the highest amount of attenuation you'll want.
;
; 000=square	; 001=bass  ; 010=pitfall	; 011=noise
; 100=buzz 	; 101=lead  ; 110=saw      	; 111=lowbass 
; -- 111 'lowbass' changed to 'lead low volume'

soundTurnArray
	byte 5, 0, 5, 10
	byte 0, 6, 10, 10

;-------------------------------------------------------------
; Sound Type Array
;-------------------------------------------------------------
; This array allows you to change the sound types
; that are encoded into the first three bits of
; notes (discusses later.)  I'd suggest leaving
; this array alone until you are pretty comfortable
; writing music for the 2600.  I rarely change these
; settings.
;
;
; Default Sound Type Setup:
; 000=square  
; 001=bass  
; 010=pitfall 
; 011=noise
; 100=buzz  
; 101=lead  
; 110=saw      
; 111=lowbass -- changed to lead low volume
;
soundTypeArray
    byte 4,6,7,8
    byte 15,12,1,12


;-------------------------------------------------------------
; Auto High Hat
;-------------------------------------------------------------
; The latest driver has built-in support to
; play a high-hat sound.  This allows you to have
; a high hat rhythm playing without having to add it to
; your pattern data.  The driver plays the high-hat
; click very short, so often you will barely notice
; any interference with your song.  It plays on
; the same oscillator as the "song2" list of patterns.
; If it is interfering with your music too much,
; just swap song1 and song2.
;
; You specify the high hat pattern in hatPattern.  Each
; bit corresponds to one 32nd note.  Set the bit to one
; to have it play on that beat, or zero to mute the high
; hat on that beat.  The pattern repeats each measure.
;
; You can also specify the measure that the high hat
; starts playing with HATSTART.  You may want to have
; and intro part without the high hat then have it
; come in later.  Or if you don't want to use it at all,
; then set HATSTART to 255.
;
; Finally, you can specify the high hat volume (0-15), the
; pitch (0-31), and the high hat sound type.  Refer to the
; table above for sound type values.  I typically use
; sound type 8 (Noise) and pitch 0 which sounds like a pretty
; good high hat.  But you may find other interesting settings.
;

hatPattern
        byte %00000000
        byte %00000000
        byte %00000000
        byte %00000000


; HATSTART equ 0
HATSTART equ 17

; HATVOLUME equ 8
HATVOLUME equ 0

; HATPITCH equ 0
HATPITCH equ 0
;HATSOUND equ 8
HATSOUND equ 8


;-------------------------------------------------------------
; Song Data
;-------------------------------------------------------------
; song1 and song2 are lists of four pattern sets to be
; played out of patternArrayH and patternArrayL.
; Both song1 and song2 will be played simlutaneously 
; by the software, one on each of the two oscillators,
; so each song should be exactly the same length or you
; may have some problems!  
;
; Each number (after "byte") refers
; to a four pattern set in the patternArrayH (loud
; patterns) or patternArrayL (softer patterns).  
;
; "song1" and "song2" must be against the left
; edge, and each "byte" statement must have at
; least one space or tab to the left of it.  I
; have only put two pattern numbers on each line
; but you can put as many as you want (each number
; separated by a comma).  A song cannot
; exceed 255 patterns.
;
; You must put a 255 at the end of the pattern list
; to let the driver know that it has reached the end.
; The player will automatically loop back to the beginning
; of the song when it reaches the end.
;
; I suggest that you comment your songs so you can
; remember what's going on where.  (Use a semicolon
; to indicate a comment)


song1

	byte 0,1
	byte 2,3

	byte 4,5
	byte 6,6
	
	byte 6,7
	byte 8,9
	
	byte 6,7
	byte 10,10
	
	; End of song marker
	byte 255


song2

	byte 11,12
	byte 13,14

	byte 15,16
	byte 17,18
	
	byte 19,20
	byte 21,22
	
	byte 19,20
	byte 23,24
	
		
	; End of song marker
	byte 255



;-------------------------------------------------------------
; Pattern Arrays
;-------------------------------------------------------------
; The pattern arrays contains sets of four patterns. The
; numbers in the song1 and song2 lists reference
; the pattern arrays.
;
; There are two pattern arrays.  Patterns in 
; patternArrayH will play louder, while patterns 
; in patternArrayL will play softer.  This gives you
; a bit more control over volume.  You can even have
; a soft and loud version of the same pattern.
;
; In my original driver, patterns were a full measure
; long.  The reason I've divided the patterns into
; fours is because it results in a lot more reuse of
; pattern data.  You can reuse patterns as much as
; you want.  For example, you may have a drum beat
; and want to add a fill.  You can reuse the first
; three patterns, and create a new fill pattern
; for the end of the measure.  This ends up saving
; a lot of space.
;
; I always put a comment
; to the right with the pattern number so when I'm 
; writing the song (above) I can easily see the number
; of the pattern.  
;
; You'll find data for each of these patterns below.
; Make sure the name in the patternArray matches the
; name below or you'll get an error.  patternArrayL
; and patternArrayH may have a maximum of 64 sets of
; 4 patterns each.
;
; Note that pattern sets in patternArrayH start at
; zero, while pattern sets in patternArrayL start at
; 128.
;


	; Higher volume patterns
patternArrayH 						; starts at 0

; *** pattern 0, channel 1 ***	
	word subptrn01, subptrn02, subptrn03, subptrn04             ;0
	word subptrn05, subptrn06, subptrn07, subptrn08             ;1
	word subptrn09, subptrn10, subptrn11, subptrn12             ;2
	word subptrn09, subptrn10, subptrn15, subptrn16             ;3
	
; *** pattern 1, channel 1 ***		
	word subptrn17, subptrn18, subptrn19, subptrn20             ;4
	word subptrn21, subptrn22, subptrn23, subptrn24             ;5
	word subptrn25, subptrn25, subptrn25, subptrn25             ;6 


; *** pattern 2, channel 1 ***	
	word subptrn25, subptrn25, subptrn39, subptrn39             ;7  -- repeated in beginning of pattern 3 (after 6)
	word subptrn41, subptrn42, subptrn43, subptrn44             ;8 
	word subptrn45, subptrn45, subptrn47, subptrn45             ;9 
	
; *** pattern 3, channel 1 -- second half ***
        word subptrn57, subptrn58, subptrn59, subptrn60             ;10 -- used twice in second half

; *** pattern 0, channel 2 ***	
	word subptrn01b, subptrn02b, subptrn03b, subptrn04b         ;11
	word subptrn05b, subptrn06b, subptrn07b, subptrn08b         ;12
	word subptrn09b, subptrn09b, subptrn11b, subptrn11b         ;13
	word subptrn09b, subptrn09b, subptrn15b, subptrn15b         ;14
	
; *** pattern 1, channel 2 ***		
	word subptrn11b, subptrn11b, subptrn19b, subptrn19b         ;15
	word subptrn21b, subptrn21b, subptrn23b, subptrn09b         ;16
	word subptrn09b, subptrn09b, subptrn27b, subptrn09b         ;17
	word subptrn11b, subptrn11b, subptrn31b, subptrn11b         ;18

; *** pattern 2, channel 2 ***	
	word subptrn33b, subptrn34b, subptrn35b, subptrn34b         ;19 -- repeated in beginning of pattern 3
	word subptrn37b, subptrn38b, subptrn39b, subptrn40b         ;20 -- repeated in beginning of pattern 3
	word subptrn09b, subptrn42b, subptrn27b, subptrn44b         ;21
	word subptrn11b, subptrn11b, subptrn31b, subptrn11b         ;22
	
; *** pattern 3, channel 2 -- second half ***
        word subptrn57b, subptrn58b, subptrn59b, subptrn60b         ;23
        word subptrn61b, subptrn57b, subptrn63b, subptrn64b         ;24

	; Lower volume patterns
patternArrayL 						; start at 128

	word mute, mute, mute, mute			;128

;-------------------------------------------------------------
; Pattern Data
;-------------------------------------------------------------
; This is where the note patterns are defined.  Each pattern
; is a quarter note long and is divided into 8 steps (32nd
; notes).  Each step in the pattern specifies the pitch
; and sound type for that pitch.  These patterns are
; arranged by fours into full measure patterns in the
; pattern arrays above.
;
; Way below you'll find data for the patterns listed in the
; pattern arrays above.  Each one has a name and is followed
; by 9 bytes (numbers) of data.  Each of
; the first 8 numbers in the data set represents 
; a 32nd note step.  The byte after that determines
; which 32nd notes are accented (louder).
;
; It is very helpful if you reuse patterns you've written.
; Find one that's similar to what you need, copy it, 
; and modify it.
; 
; Note that the percent sign means that you
; are entering a binary number.
;
;
; Note Encoding
; ----------------------------------------------------------
;
; The 8 note numbers are encoded with sound type and pitch.
; I put two 32nd notes per line like this:
;
;	byte %00111000, %00111000
;
; The first three bits (1's and  0's) determine the 
; sound type according to the following table:
;
; 000 Square  (high square wave)
; 001 Bass    (fat bass sound)
; 010 Pitfall (sound of hitting a lot in pitfall)
; 011 Noise   (white noise)
; 100 Buzz    (hard buzzy sound)
; 101 Lead    (lower square wave)
; 110 Saw     (sounds kind of like a sawtooth wave)
; 111 Engine  (engine sound) -- changed to lead low volume
;
;
; The remaining 5 bits determine the pitch.
;
; 11111 is a very low pitch
; 00001 us a very high pitch
; 00100 is somewhere in between
;
; (!) Note that 255 or %11111111 means no sound (a rest)
;
; Some examples:
;
; %00111100 = bass with a low pitch
; %10000010 = buzz sound with a high pitch
; %11100101 = engine sound with a medium pitch
; %11111111 = no sound
;
;
; The pitch on the Atari is not all on a musical scale,
; so you'll end up with some really out-of-tune stuff
; if you aren't careful.  Refer to my 2600 music 
; programming guide for some sets of in-tune notes.
;
;
; Accent Encoding
; ----------------------------------------------------------
;
; There will be ninth number at the end of each pattern like:
;  
;	byte %10001000
;
; This determines which notes are accented.  Good accents can 
; really make a pattern a lot better.  Notice there are 
; 8 bits, and conveniently they correspond to each of the 8
; notes in the pattern!  The way I have it set up above, 
; accents fall on each 8th note.  
;
; 1 = accent (loud), 0 = no accent (no as loud)
; 
; To just make the whole beat quieter, use all zeros:
;
; byte %00000000
;
; To make the whole beat louder:
;
; byte %11111111
;
; Here's an accent pattern I use often:
;
; byte %10001000
;
;
;
; Patterns:
; ----------------------------------------------------------


; *********** pattern 00 ***********
subptrn01
        byte %10111101, 255 ; f3
        byte %11111101, 255 
        byte %10110111, 255 ; a3 
        byte %11110111, 255 
        
        byte %10001000
        
subptrn02  
	byte %10110011, 255 ; c4 
        byte %11110011, 255 
        byte %10101110, 255 ; f4 
        byte %11101110, 255 
        
        byte %10001000
	
subptrn03
	byte %10111000, 255 ; g#3 
        byte %11111000, 255 
        byte %10110101, 255 ; a#3 
        byte %11110101, 255 
        
        byte %10001000
		
subptrn04  		
	byte %10110011, 255 ; c4
        byte %11110011, 255 
        byte %10101100, 255 ; g4
        byte %11101100, 255 
        
        byte %10001000

subptrn05
	byte %10110010, 255 ; c#4
        byte %11110010, 255 
        byte %10110000, 255 ; d#4
        byte %11110000, 255 
        byte %10001000

subptrn06
        
	byte %10101110, 255 ; f4
	byte %11101110, 255 
	byte %10101011, 255 ; a4 - should really have been g#4
        byte 255, 255 
        
        byte %10000000
        
subptrn07
        byte %10110000, 255 ; d#4
	byte %11110000, 255 
	byte %10101000, 255 ; d5
        byte 255, 255 
        
        byte %10000000


subptrn08
        byte %10101111, 255 ; e4
	byte %11101111, 255 
	byte %10101001, 255 ; c5
        byte 255, 255 
        
        byte %10000000

      
subptrn09
	byte %10111101, 255  ; f3
	byte %11111101, 255 
	byte %10101110, 255  ; f4
        byte %11101110, 255 
        
        byte %10001000

        
subptrn10
        byte %11001111, 255  ; c3
	byte 255, 255 
        byte %10111001, 255  ; g3
        byte %11111001, 255 
        
        byte %10001000
      
	
subptrn11 
        byte %11001100, 255  ; d#3
	byte 255, 255 
	byte %10101100, 255  ; g4
        byte %11101100, 255 
        
        byte %00001000	


subptrn12
        byte %10111001, 255  ; g3
        byte %11111001, 255 
        byte %11001100, 255 ; d#3
        byte 255, 255 
        
        byte %10000000	


subptrn15
	byte %10110010, 255  ; c#4
        byte %11110010, 255 
        byte %00010101, 255 ; f5 
        byte 255, 255 
        
        byte %10000000
		
subptrn16
        	
        byte %10101110, 255  ; f4 
        byte %11101110, 255 
	byte %10110010, 255  ; c#4 
        byte %11110010, 255 
        
        byte %10001000


; *********** pattern 01 ***********
subptrn17
        byte %11001100, 255  ; d#3
	byte 255, 255 
	byte %10110000, 255 ; d#4 
        byte %11110000, 255 
        
        byte %00001000	
	

subptrn18
        byte %11010001, 255 ; a#2 
	byte 255, 255 
	byte %10111101, 255 ; f3 
        byte %11111101, 255 
        
        byte %00001000	
        
subptrn19
        byte %10110100, 255 ; h3 
	byte %11110100, 255 
	byte %00011000, 255 ; d#5
        byte 255, 255 
        
        byte %10000000	

subptrn20
        byte %10110000, 255 ; d#4
	byte %11110000, 255 
        byte %10110100, 255 ; h3 
        byte %11110100, 255 
        
        byte %10001000	

subptrn21
        byte %11001111, 255 ; c3
	byte 255, 255 
        byte %10101111, 255 ; e4 
        byte %11101111, 255 
        
        byte %00001000


subptrn22
        byte %11001101, 255 ; d3 
	byte 255, 255 
        byte %10101110, 255  ; f4 
        byte %11101110, 255 
        
        byte %00001000	
			
subptrn23

        byte %10110101, 255 ; a#3 
	byte %11110101, 255 
	byte %10110101, 255 ; a#3
        byte %11110101, 255 
        
        byte %10001000	

	
subptrn24
        byte %10101010, 255  ; a#4
	byte %11101010, 255 
        byte %10101110, 255 ; f4 
        byte %11101110, 255 
        
        byte %10001000	

        				
subptrn25
        byte %10101110, 255 ; f4
	byte %11101110, 255 
	byte %10101110, 255 ; f4
        byte %11101110, 255 
        
        byte %00001000	

; *********** pattern 02 ***********


subptrn39

        byte %10110000, 255 ; d#4
	byte %11110000, 255 
        byte %10110000, 255 ; d#4
        byte %11110000, 255 
        		
	byte %10001000	

	
	
subptrn41
	byte %10101110, 255 ; f4
	byte %11101110, 255 
        byte %00010101, 255 ; f5
        byte 255, 255 
        
        byte %10000000	

subptrn42	
	byte %10101110, 255 ; f4 
	byte %11101110, 255 
        byte %00011000, 255 ; d#5
        byte 255, 255 
        
        byte %10000000	
        	
subptrn43
	byte %10101110, 255 ; f4
	byte %11101110, 255         			
        byte %10101000, 255 ; d5
	byte 255, 255 

        byte %10000000	
	        		
subptrn44
	byte %10101110, 255 ; f4 
	byte %11101110, 255 		        			
        byte %10101001, 255 ; c5 
        byte 255, 255 
        
        byte %10000000	
        
subptrn45
        byte %10110000, 255 ; d#4
	byte %11110000, 255 
  	byte %00011000, 255; d#5
        byte 255, 255 
        
        byte %10000000	


subptrn47
        byte %10110000, 255 ; d#4 
	byte %11110000, 255 
        byte %10101010, 255 ; a#4 
        byte %11101010, 255 
        
        byte %10001000	
		        

subptrn57
        byte %10101011, 255; a4 
	byte %11101011, 255 
        byte %10101110, 255 ; f4
        byte %11101110, 255 
        
        byte %10001000	

subptrn58
        byte %10110011, 255 ; c4
	byte %11110011, 255 
        byte %10110111, 255 ; a3
        byte %11110111, 255 
        
        byte %10001000	

subptrn59
        byte %10101100, 255 ; g4 
	byte %11101100, 255 
	byte %10110000, 255 ; d#4
        byte %11110000, 255 
        
        byte %10001000	


subptrn60

        byte %10110101, 255 ; a#3
	byte %11110101, 255 
        byte %11001100, 255 ; d#3
        byte 255, 255 
        
        byte %10000000	


; *********** pattern 00 ***********
subptrn01b
        byte 255, %11010111 ; f2
        byte 255, 255 
        byte 255, %11001111 ; c3
        byte 255, 255 
        
        byte %00000000
        
subptrn02b 
	byte 255, %10111101 ; f3
        byte 255, 255 
        byte 255, %10111000 ; g#3
        byte 255, 255 
        
        byte %01000100
	
subptrn03b
	byte 255, %11011010 ; d#2
        byte 255, 255 
        byte 255, %11001101 ; d3
        byte 255, 255 
        
        byte %00000000
		
subptrn04b 		
	byte 255, %11001100 ; d#3
        byte 255, 255 
        byte 255, %10110101 ; a#3
        byte 255, 255 
        
        byte %00000100

subptrn05b
	byte 255, %11011101 ; c#2
        byte 255, 255 
        byte 255, %11011101 ; c#2
        byte 255, 255 
        byte %00000000

subptrn06b
	byte 255, %11001110 ; c#3
	byte 255, 255 
	byte 255, %11011101 ; c#2
        byte 255, 255 
        
        byte %00000000
        
subptrn07b
        byte 255, %11001100 ; d#3
	byte 255, 255 
	byte 255, %10101010 ; a#4
        byte 255, 255 
        
        byte %00000100

subptrn08b
        byte 255, %10111111 ; e3
	byte 255, 255 
	byte %10101011, 255 ; a4 - should really have been g#4
        byte 255, 255 
        
        byte %00000000
      
subptrn09b
	byte 255, %11010111 ; f2     
	byte 255, 255 
	byte 255, %11010111 ; f2
        byte 255, 255 
        
        byte %00000000

        
	
subptrn11b
        byte 255, %11011010 ; d#2
	byte 255, 255 
	byte 255, %11011010 ; d#2
        byte 255, 255 
        
        byte %00000000	


subptrn15b
	byte 255, %11001110 ; c#3
        byte 255, 255 
        byte 255, %11001110 ; c#3        
        byte 255, 255 
        
        byte %00000000
		


; *********** pattern 01 ***********
        
subptrn19b
        byte 255, %11010000 ; h2                        
	byte 255, 255 
	byte 255, %11010000 ; h2
        byte 255, 255 
        
        byte %00000000	


subptrn21b
        byte 255, %11011111 ; c2 
	byte 255, 255 
        byte 255, %10110011 ; c4
        byte 255, 255 
        
        byte %00000100	

			
subptrn23b

        byte 255, %11010001 ; a#2
	byte 255, 255 
	byte 255, %11010001 ; a#2
        byte 255, 255 
        
        byte %00000000	

	

subptrn27b
        byte 255, %10111101 ; f3
	byte 255, %11111101 
	byte 255, %10111101 ; f3
        byte 255, %11111101 
        
        byte %01000100	

subptrn31b
        byte 255, %11001100 ; d#3
	byte 255, 255 
	byte 255, %11001100 ; d#3
        byte 255, 255 
        
        byte %01000100	


; *********** pattern 02 ***********

subptrn33b
	byte 255, %11010111 ; f2
	byte 255, 255 
	byte 255, %10101011 ; a4
        byte 255, %11101011 
        
        byte %00000100	

subptrn34b
	byte 255, %11010111 ; f2        
	byte 255, 255 
        byte 255, %10101010 ; a#4
        byte 255, %11101010 
        
        byte %00000100	


subptrn35b
	byte 255, %10111101 ; f3
	byte 255, %11111101 
	byte 255, %10101011 ; a4
        byte 255, %11101011 
        
        byte %01000100
		        
        		
subptrn37b       		
        byte 255, %11011010 ; d#2
	byte 255, 255 
	byte 255, %10101011 ; a4
        byte 255, 255 
        
        byte %00000100	

subptrn38b
        byte 255, %11011010 ; d#2
	byte 255, 255 
        byte 255, %10101010 ; a#4
        byte 255, 255 
        
        byte %00000100	

subptrn39b

        byte 255, %11001100 ; d#3
	byte 255, 255 
        byte 255, %10101100 ; g4
        byte 255, 255 
        		
	byte %00000100	

subptrn40b

        byte 255, %11011010 ; d#2
	byte 255, 255 
	byte 255, %10101011 ; a4 - should really have been g#4
        byte 255, 255 
        		
	byte %00000000	
	
	

subptrn42b
	byte 255, %11010111 ; f2        
	byte 255, 255 
        byte 255, %10101001 ; c5
        byte 255, 255 
        
        byte %00000100	
        	
	        		
subptrn44b
	byte 255, %11010111 ; f2        
	byte 255, 255 		        			
        byte 255, %10101011 ; a4 - should really have been g#4
        byte 255, 255 
        
        byte %00000000	
        
			        

subptrn57b
        byte 255, %10101110 ; f4
	byte 255, 255 
        byte 255, %10110011 ; c4
        byte 255, 255 
        
        byte %01000000	

subptrn58b
        byte 255, %10110111 ; a3
	byte 255, 255 
        byte 255, %10111101 ; f3	                			
        byte 255, 255 
        
        byte %00000100	
        

subptrn59b

        byte 255, %10110000 ; d#4
	byte 255, 255 
	byte 255, %10110101 ; a#3
        byte 255, 255 
        
        byte %01000100	


subptrn60b

        byte 255, %10111001 ; g3
	byte 255, 255 
        byte 255, %11011010 ; d#2	
        byte 255, 255 
        
        byte %01000000	

subptrn61b
        
	byte 255, %10101001 ; c5
	byte 255, 255 
        byte 255, %10101011 ; a4	        		        
        byte 255, 255 
                	
        byte %01000100	


subptrn63b
        byte 255, %10110101 ; a#3
	byte 255, 255 
	byte 255, %10111001 ; g3
        byte 255, 255 
                	
        byte %01000100	     

subptrn64b

        byte 255, %11001100 ; d#3
	byte 255, 255 
        byte 255, %11011010 ; d#2
        byte 255, 255 
                	
        byte %00000000	     
	        		
; Muted pattern.

mute
	byte 255,255,255,255
	byte 255,255,255,255

	byte 255
